@@ -4,6 +4,10 @@ from AuthX.services.password import PasswordService
 from AuthX.services.search import SearchService
 from AuthX.services.social import SocialService
 
+"""
+    Initialize all services
+"""
+
 __all__ = [
     "AdminService",
     "AuthService",
